Docker.Commands.Generic (docker_wrapper v0.1.2)

Copy Markdown View Source

Escape hatch for running arbitrary Docker commands.

Use this when there's no typed command module for what you need.

Examples

Docker.Commands.Generic.new(["system", "events", "--filter", "type=container"])
|> Docker.generic()

Summary

Functions

Creates a generic command from a list of arguments.

Types

t()

@type t() :: %Docker.Commands.Generic{args: [String.t()]}

Functions

new(args)

@spec new([String.t()]) :: t()

Creates a generic command from a list of arguments.